//
//  SimpleCustomLegend.m
//  MakingOwnLegend
//


#import "SimpleCustomLegend.h"
@interface SimpleCustomLegend()
{
    UIScrollView* _scrollView;
    float _totalHeight, _totalWidth, _maxHeight, _maxWidth, _spacing;
    int _itemCount;
}
@end

@implementation SimpleCustomLegend

- (id)initWithFrame:(CGRect)frame
{
    self = [super initWithFrame:frame];
    if (self) {
        // Initialization code
        _scrollView = [[UIScrollView alloc]initWithFrame:CGRectMake(0, 0, self.frame.size.width, self.frame.size.height)];
        _scrollView.backgroundColor = [UIColor clearColor];
        _scrollView.autoresizingMask = UIViewAutoresizingFlexibleHeight | UIViewAutoresizingFlexibleWidth;
        [self addSubview:_scrollView];
    }
    return self;
}


-(void)updateItems
{
    CGFloat totalWidth = _totalWidth;
    CGFloat totalHeight = _totalHeight;
    if(self.orientation == IGOrientationHorizontal)
        totalHeight = _maxHeight;
    else
        totalWidth = _maxWidth;
    
    CGFloat availWidth = self.frame.size.width;
    CGFloat availHeight = self.frame.size.height;
    CGFloat left = 0, top = 0;
    CGFloat additionalXSpacing = 0, additionalYSpacing = 0;;
    
    if(totalWidth < availWidth)
    {
        if(self.horizontalAlignment == IGHorizontalAlignRight)
        {
            left = availWidth - totalWidth;
        }
        else if(self.horizontalAlignment == IGHorizontalAlignCenter)
        {
            left =  availWidth/2 - totalWidth/2;
        }
        else if(self.horizontalAlignment == IGHorizontalAlignStretch)
        {
            CGFloat diff = availWidth - totalWidth;
            additionalXSpacing = diff/(_itemCount + 1);
            left = additionalXSpacing;
        }
    }
    
    if(totalHeight < availHeight)
    {
        if(self.verticalAlignment == IGVerticalAlignBottom)
        {
            top = availHeight - totalHeight;
        }
        else if(self.verticalAlignment == IGVerticalAlignCenter)
        {
            top = availHeight/2 - totalHeight/2;
        }
        else if(self.verticalAlignment == IGVerticalAlignStretch)
        {
            CGFloat diff = availHeight - totalHeight;
            additionalYSpacing = diff/(_itemCount + 1);
            top = additionalYSpacing;
        }
    }
    
    CGFloat contentWidth = 0, contentHeight = 0;
    for(UIView* view in _scrollView.subviews)
    {
        CGFloat height = view.frame.size.height, width = view.frame.size.width;
        CGFloat x = 0, y = 0;
        if(self.orientation == IGOrientationHorizontal)
        {
            // so for this custom legend we want to make the horizontal more into a vertial scrolling but with
            // better horizontal space usage
            
            x = left;
            
            // if the label can fit on the current line
            float viewWidth =view.frame.size.width ;
            
            // if the view that shows the paret of the legend can fit
            // put it on the current horizontal line
            if (contentWidth + viewWidth <= self.frame.size.width)
            {
                left += view.frame.size.width + _spacing + additionalXSpacing;
                
                y = top;
                
                contentWidth = left;
                contentHeight = self.frame.size.height  - (_spacing + additionalXSpacing);
            }
            else
            {
                // otherwise we move it to the next line of the legend.
                x = 0;
                top+= view.frame.size.height;
                y=top;
            }
            
            view.frame = CGRectMake(x, y, width, height);
        }
        else
        {
            // This code would handle Vertical orientation and isn't specialized in this case.
            x = left;
            
            y = top;
            top += view.frame.size.height + _spacing + additionalYSpacing;
            
            contentWidth = self.frame.size.width;
            contentHeight = top - (_spacing + additionalYSpacing);
        
            view.frame = CGRectMake(x, y, width, height);
        }
        
        
    }
    
    // Since we are changin the behavior for horizontal orientation:
    // If the orientation is horizontal, then we want to scroll vertially.  So we change the content size
    // of the scroll view to fix the width to the width of the view, and the height ot as much height as we got
    if (self.orientation==IGOrientationVertical)
        _scrollView.contentSize = CGSizeMake(contentWidth, contentHeight);
    else
        _scrollView.contentSize = CGSizeMake(self.frame.size.width, contentHeight);
    
}

@end
